<?php
$lang['info_detail_returnid'] = 'This preference is used to determine a page (and therefore a template) to use to view detail pages.  Individualized News Detail URLS will not work if this parameter is not set to a valid page.  Additionally, if this preference is set, and no detailpage parameter is provided on the news tag, then this value will be used for detail links';
$lang['title_detail_returnid'] = 'Default page to use for detail views';
$lang['title_submission_settings'] = 'News Submission Settings';
$lang['title_fesubmit_settings'] = 'Frontend Submit Settings';
$lang['title_notification_settings'] = '通知設定';
$lang['title_detail_settings'] = '詳細表示設定';
$lang['error_invalidurl'] = 'Invalid URL <em>(maybe it is already used, or there are invalid characters)</em>';
$lang['url'] = 'URL';
$lang['expired_searchable'] = 'Expired articles can appear in search results';
$lang['helpshowall'] = 'Show all articles, irrespective of end date';
$lang['error_invaliddates'] = 'One or more of the dates entered were invalid';
$lang['notify_n_draft_items_sub'] = '%d News article(s)';
$lang['notify_n_draft_items'] = 'You have %s that is/are not published';
$lang['unlimited'] = '上限値なし';
$lang['none'] = 'なし';
$lang['anonymous'] = 'Anonymous';
$lang['unknown'] = '知らない。';
$lang['fesubmit_redirect'] = 'PageID or alias to redirect to after a news article has been submitted via the fesubmit action';
$lang['allow_summary_wysiwyg'] = 'Allow using a WYSIWYG editor on the summary field';
$lang['title_browsecat_template'] = 'Browse Category Template Editor';
$lang['title_browsecat_sysdefault'] = 'Default Browse category Template';
$lang['browsecattemplate'] = 'カテゴリ・テンプレートを見る。';
$lang['error_filesize'] = 'An uploaded file exceeded the maximum allowed size';
$lang['post_date_desc'] = 'Post Date Descending';
$lang['post_date_asc'] = 'Post Date Ascending';
$lang['expiry_date_desc'] = 'Expiry Date Descending';
$lang['expiry_date_asc'] = 'Expiry Date Ascending';
$lang['title_desc'] = 'タイトル降順';
$lang['title_asc'] = 'タイトル昇順';
$lang['status_desc'] = 'ステータス降順';
$lang['status_asc'] = 'ステータス昇順';
$lang['fesubmit_status'] = 'The status of news articles submitted via the frontend';
$lang['error_invalidfiletype'] = 'Cannot upload this type of file';
$lang['error_upload'] = 'Problem occurred uploading a file';
$lang['error_movefile'] = 'Could not create file: %s';
$lang['error_mkdir'] = 'Could not create directory: %s';
$lang['expiry_interval'] = 'The number of days (by default) before an article expires (if expiry is selected)';
$lang['removed'] = '削除しました。';
$lang['msg_contenttype_removed'] = 'The news content type has been removed.  Please place {news} tags with appropriate parameters into your page template or into your page content to replace this functionality.';
$lang['delete_selected'] = '選択した項目を削除しました。';
$lang['areyousure_deletemultiple'] = 'Are you sure you want to delete all of these news articles?\\nThis action cannot be undone!';
$lang['error_templatenamexists'] = 'A template by that name already exists';
$lang['error_noarticlesselected'] = 'No Articles Were Selected';
$lang['reassign_category'] = 'Change Category To';
$lang['select'] = '選択';
$lang['approve'] = 'ステータスを「公開」に設定しました。';
$lang['revert'] = 'ステータスを「ドラフト」に設定しました。';
$lang['hide_summary_field'] = 'Hide the summary field when adding or editing articles';
$lang['textbox'] = 'テキスト';
$lang['checkbox'] = 'チェックボックス';
$lang['textarea'] = 'テキストエリア';
$lang['file'] = 'ファイル';
$lang['auto_create_thumbnails'] = 'Automatically create thumbnail files for files with these extensions';
$lang['allowed_upload_types'] = 'Allow only files with these extensions to be uploaded';
$lang['fielddefupdated'] = '項目定義を更新しました。';
$lang['editfielddef'] = '項目定義の編集';
$lang['up'] = '上';
$lang['down'] = '下';
$lang['fielddefdeleted'] = 'Field Definition Deleted';
$lang['nameexists'] = 'A field by that name already exists';
$lang['notanumber'] = 'Maximum Length is Not a Number';
$lang['fielddef'] = '項目定義';
$lang['fielddefadded'] = '項目定義を追加しました。';
$lang['public'] = '公開';
$lang['type'] = 'タイプ';
$lang['info_maxlength'] = 'The maximum length only applies to text input fields.';
$lang['maxlength'] = '最大長さ';
$lang['addfielddef'] = 'Add Field Definition';
$lang['customfields'] = 'Field Definitions';
$lang['deprecated'] = 'unsupported';
$lang['subject_newnews'] = 'A new News article has been posted';
$lang['email_subject'] = 'The Subject of the outgoing email';
$lang['email_template'] = 'The format of the email message';
$lang['formsubmit_emailaddress'] = 'Email address to receive notification of news submission';
$lang['extra'] = 'Extra';
$lang['uploadscategory'] = 'カテゴリのアップロード';
$lang['title_available_templates'] = 'Available Templates';
$lang['resettodefault'] = 'Reset to Factory Defaults';
$lang['title_form_template'] = 'Form Template Editor';
$lang['title_detail_template'] = 'Detail Template Editor';
$lang['title_summary_template'] = 'Summary Template Editor';
$lang['prompt_templatename'] = 'テンプレート名';
$lang['prompt_template'] = 'テンプレート・ソース';
$lang['title_form_sysdefault'] = 'Default Form Template';
$lang['title_summary_sysdefault'] = 'Default Summary Template';
$lang['title_detail_sysdefault'] = 'Default Detail Template';
$lang['info_sysdefault2'] = '<strong>Note:</strong> This tab contains text areas to allow you to edit a set of templates that are displayed when you create a \'new\' summary, detail, or form template.  Changing content in this tab, and clicking \'submit\' will <strong>not effect any current displays</strong>.';
$lang['info_sysdefault'] = '<em>(the content used by default when a new template is created)</em>';
$lang['template'] = 'テンプレート';
$lang['prompt_name'] = '名';
$lang['prompt_default'] = 'デフォルト';
$lang['prompt_newtemplate'] = 'テンプレートを作成する。';
$lang['help_pagelimit'] = 'Maximum number of items to display (per page).  If this parameter is not supplied all matching items will be displayed.  If it is, and there are more items available than specified in the pararamter, text and links will be supplied to allow scrolling through the results';
$lang['prompt_page'] = 'ページ';
$lang['firstpage'] = '<<';
$lang['prevpage'] = '<';
$lang['nextpage'] = '>';
$lang['lastpage'] = '>>';
$lang['prompt_of'] = 'of';
$lang['prompt_pagelimit'] = 'Page Limit';
$lang['prompt_sorting'] = 'ソート';
$lang['title_filter'] = 'フィルタ';
$lang['published'] = '公開';
$lang['draft'] = 'ドラフト';
$lang['expired'] = 'Expired';
$lang['author'] = '作成者';
$lang['sysdefaults'] = 'デフォルトに戻す';
$lang['restoretodefaultsmsg'] = 'テンプレートの設定をデフォルトに戻します。本当に実行しますか？';
$lang['addarticle'] = '記事の追加';
$lang['articleadded'] = '記事を追加しました。';
$lang['articleupdated'] = '記事を更新しました。';
$lang['articledeleted'] = '記事を削除しました。';
$lang['addcategory'] = 'カテゴリの追加';
$lang['categoryadded'] = 'カテゴリを追加しました。';
$lang['categoryupdated'] = 'カテゴリを更新しました。';
$lang['categorydeleted'] = 'カテゴリを削除しました。';
$lang['addnewsitem'] = 'ニュース項目の追加';
$lang['allcategories'] = '全カテゴリ';
$lang['allentries'] = '全エントリー';
$lang['areyousure'] = '削除しますか?';
$lang['articles'] = '記事';
$lang['cancel'] = 'キャンセル';
$lang['category'] = 'カテゴリ';
$lang['categories'] = 'カテゴリ';
$lang['default_category'] = 'デフォルトカテゴリ';
$lang['content'] = 'コンテンツ';
$lang['dateformat'] = '%sは有効なフォーマットではありません。「yyyy-mm-dd hh:mm:ss」の必要があります。';
$lang['delete'] = '削除';
$lang['description'] = 'ニュースエントリーの追加、編集、削除';
$lang['formtemplate'] = 'Form Templates';
$lang['detailtemplate'] = 'テンプレートの詳細';
$lang['default_templates'] = 'デフォルト・テンプレート';
$lang['detailtemplateupdated'] = '更新された詳細テンプレートは正常にデータベースに保存されました。';
$lang['displaytemplate'] = 'テンプレートの表示';
$lang['edit'] = '編集';
$lang['enddate'] = '終了日';
$lang['endrequiresstart'] = '終了日を入力する際に開始日も必要';
$lang['entries'] = '%sのエントリー';
$lang['status'] = 'ステータス';
$lang['expiry'] = '有効期限';
$lang['filter'] = 'フィルター';
$lang['more'] = 'さらに表示';
$lang['category_label'] = 'カテゴリ:';
$lang['author_label'] = '投稿者:';
$lang['moretext'] = 'さらにテキストを表示';
$lang['name'] = '名前';
$lang['news'] = 'ニュース';
$lang['news_return'] = '戻る';
$lang['newcategory'] = '新規カテゴリ';
$lang['needpermission'] = 'この機能を利用するには\'%s\'パーミッションが必要です。';
$lang['nocategorygiven'] = 'カテゴリが存在しません。';
$lang['startdatetoolate'] = 'The Start Date is too late (after end date?)';
$lang['nocontentgiven'] = 'コンテンツが存在しません。';
$lang['noitemsfound'] = 'カテゴリ%sに対する項目がありません。';
$lang['nopostdategiven'] = '投稿日付がありません。';
$lang['note'] = '<em>注意:</em> 日付は\'yyyy-mm-dd hh:mm:ss\'フォーマットの必要があります。';
$lang['notitlegiven'] = 'タイトルが存在しません。';
$lang['nonamegiven'] = '名前が存在しません。';
$lang['numbertodisplay'] = '表示数(空欄の場合は全てのレコードが表示されます)';
$lang['print'] = '印刷';
$lang['postdate'] = '投稿日';
$lang['postinstall'] = 'ニュース項目を管理するユーザーには"ニュースを修正"パーミッションを設定する必要があります。';
$lang['selectcategory'] = 'カテゴリの選択';
$lang['showchildcategories'] = '子カテゴリを表示';
$lang['sortascending'] = '昇順並び替え';
$lang['startdate'] = '開始日';
$lang['startoffset'] = '○番目の項目から表示';
$lang['startrequiresend'] = '開始日を入力する際に終了日も必要';
$lang['submit'] = '送信';
$lang['summary'] = '要約';
$lang['summarytemplate'] = '要約テンプレート';
$lang['summarytemplateupdated'] = 'ニュース要約テンプレートは正常に更新されました。';
$lang['title'] = 'タイトル';
$lang['options'] = 'オプション';
$lang['optionsupdated'] = 'オプションは正常に更新されました。';
$lang['useexpiration'] = '期限切れ日付を使用';
$lang['eventdesc-NewsArticleAdded'] = '記事の追加時に送信';
$lang['eventhelp-NewsArticleAdded'] = '<p>記事の追加時に送信</p>
<h4>パラメーター</h4>
<ul>
<li>\\"news_id\\" - ニュース記事のID</li>
<li>\\"category_id\\" -  該当記事に対するカテゴリーのID</li>
<li>\\"title\\" - 記事のタイトル</li>
<li>\\"content\\" - 記事の内容</li>
<li>\\"summary\\" - 記事の要約</li>
<li>\\"status\\" - 記事の状態 ("ドラフト" 又は "公開")</li>
<li>\\"start_time\\" - 記事の公開開始日</li>
<li>\\"end_time\\" - 記事の公開終了日</li>
</ul>
';
$lang['eventdesc-NewsArticleEdited'] = '記事の編集時に送信';
$lang['eventhelp-NewsArticleEdited'] = '<p>記事の編集時に送信</p>
<h4>パラメーター</h4>
<ul>
<li>\\"news_id\\" - ニュース記事のID</li>
<li>\\"category_id\\" - 該当記事に対するカテゴリーのID</li>
<li>\\"title\\" - 記事のタイトル</li>
<li>\\"content\\" - 記事の内容</li>
<li>\\"summary\\" - 記事の要約</li>
<li>\\"status\\" - 記事の状態 ("ドラフト" 又は "公開")</li>
<li>\\"start_time\\" - 記事の公開開始日</li>
<li>\\"end_time\\" - 記事の公開終了日</li>
</ul>
';
$lang['eventdesc-NewsArticleDeleted'] = '記事の削除時に送信';
$lang['eventhelp-NewsArticleDeleted'] = '<p>記事の削除時に送信</p>
<h4>パラメーター</h4>
<ul>
<li>\\"news_id\\" - ニュース記事のID</li>
</ul>
';
$lang['eventdesc-NewsCategoryAdded'] = 'カテゴリーの追加時に送信';
$lang['eventhelp-NewsCategoryAdded'] = '<p>カテゴリーの追加時に送信</p>
<h4>パラメーター</h4>
<ul>
<li>\\"category_id\\" - ニュースカテゴリーのID</li>
<li>\\"name\\" - ニュースカテゴリーの名前</li>
</ul>
';
$lang['eventdesc-NewsCategoryEdited'] = 'カテゴリの編集時に送信';
$lang['eventhelp-NewsCategoryEdited'] = '<p>カテゴリの編集時に送信</p>
<h4>パラメーター</h4>
<ul>
<li>\\"category_id\\" - ニュースカテゴリーのID</li>
<li>\\"name\\" - ニュースカテゴリーの名前</li>
</ul>
';
$lang['eventdesc-NewsCategoryDeleted'] = 'カテゴリの削除時に送信';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>カテゴリの削除時に送信</p>
<h4>パラメーター</h4>
<ul>
<li>\\"category_id\\" - ニュースのID</li>
</ul>
';
$lang['help_articleid'] = 'This parameter is only applicable to the detail view.  It allows specifying which news article to display in detail mode.  If the special value -1 is used, the system will display the newest, published, non expired article.';
$lang['helpnumber'] = '表示できる項目の最大数の値 -- 空欄の場合は全項目を表示';
$lang['helpstart'] = '○番目の項目からスタート -- 空欄の場合は最初からスタート';
$lang['helpcategory'] = '該当カテゴリとその子カテゴリの項目だけを表示。空欄の場合は全カテゴリを表示。';
$lang['helpmoretext'] = '要約のサイズを超えている場合に、ニュース項目を最後まで表示します。デフォルトは"さらに表示..."。';
$lang['helpsummarytemplate'] = '要約記事の表示に別のテンプレートを利用。 ファイルはmodules/News/templatesに置く必要があります。';
$lang['helpformtemplate'] = 'Use a database template for displaying the article submission form. This template must exist and be visible in the form templates tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used.';
$lang['helpbrowsecattemplate'] = 'Use a database template for displaying the category browser. This template must exist and be visible in the Browse Category Templates tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used.';
$lang['helpdetailtemplate'] = '記事詳細の表示に別のテンプレートを使用。ファイルはmodules/News/templatesに置く必要があります。';
$lang['helpsortby'] = '並び替えの優先項目。項目は: "news_date"、"summary"、"news_data"、"news_category"、"news_title"。デフォルトは"news_date"。';
$lang['helpsortasc'] = 'ニュース項目を昇順に並べ替え。';
$lang['helpdetailpage'] = 'ニュース詳細を表示するページ。ページのエイリアスまたはIDを使用できます。記事概要と異なるテンプレートで表示させる場合に使います。';
$lang['helpshowarchive'] = 'Show only expired news articles.';
$lang['helpbrowsecat'] = 'Shows a browseable category list.';
$lang['helpaction'] = 'Override the default action.  Possible values are \'default\' to display the summary view, and \'fesubmit\' to display the frontend form for allowing users to submit news articles on the front end.';
$lang['help'] = '	<h3>何ができるのでしょうか?</h3>
	<p>ニュースはページにニュースイベントを表示するモジュールで、多くの機能があり、例えばブログのような利用ができます。モジュールがインストールされると、ニュース管理ページが管理メニューに追加され、ニュースの管理はメニューから利用できます。ニュースカテゴリーが一旦作成、選択されると、該当カテゴリーのニュース項目がリスト表示されます。そこから、そのニュース項目の追加、編集、削除等が行えます。</p>
	<h3>セキュリティ</h3>
	<p>利用ユーザーは、入力や編集等の作業を行う為に、必ず\'ニュースの修正\'パーミッションを持ったグループに所属する必要があります。</p>
	<h3>使用方法</h3>
	<p>もっとも簡単な利用方法はcms_moduleタグと合わて使うことです。この方法はモジュールをテンプレートやページのどこかニュース項目を表示したい場所に挿入することです。コードの形式は以下のようになります： <code>{cms_module module="news" number="5" category="beer"}</code></p>';
$lang['utma'] = '156861353.1025915730.1283783986.1283783986.1283783986.1';
$lang['utmb'] = '156861353.1.10.1283783986';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1283783986.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['qca'] = 'P0-494958194-1283783986906';
?>